<?php
/**
 * Plugin Name:       Webyx
 * Description:       Create amazing fullpage fullscreen scrolling websites with our fast, configurable and easy block for Gutenberg.
 * Requires at least: 5.7
 * Requires PHP:      7.2
 * Version:           1.1.0
 * Author:            Terenzio Censoni & Rodolfo Cucchiella
 * Author URI:        https://webyxforgutenberg.com/
 * License:           GPL-3.0-or-later
 * License URI:       https://www.gnu.org/licenses/gpl-3.0.html
 * Text Domain:       webyx
 * @package           webyx
 */
  if ( ! defined( 'ABSPATH' ) ) {
    exit;
  }
  define( 'WEBYX_FG__FILE__', __FILE__ );
  define( 'WEBYX_FG_PATH', plugin_dir_path( WEBYX_FG__FILE__ ) );
  define( 'WEBYX_FG_WP_MIN_VERSION', '5.7' );
  define( 'WEBYX_FG_PHP_MIN_VERSION', '7.2' );
  define( 'WEBYX_FG_ASSET_MIN', true );
  define( 'WEBYX_FG_REVIEW_THRESHOLD_DATE', '-7 days' );
  if ( ! version_compare( PHP_VERSION, WEBYX_FG_PHP_MIN_VERSION, '>=' ) ) {
		function webyx_fg_fail_php_version () {
			$message      = sprintf( esc_html__( 'Webyx for Gutenberg plugin requires PHP version %s+, plugin is currently NOT RUNNING.' ), WEBYX_FG_PHP_MIN_VERSION );
			$html_message = sprintf( '<div class="error">%s</div>', wpautop( $message ) );
			echo wp_kses_post( $html_message );
		}
		add_action( 'admin_notices', 'webyx_fg_fail_php_version' );
	} else if ( ! version_compare( get_bloginfo( 'version' ), WEBYX_FG_WP_MIN_VERSION, '>=' ) ) {
		function webyx_fg_fail_wp_version () {
			$message      = sprintf( esc_html__( 'Webyx for Gutenberg plugin requires WordPress version %s+. Because you are using an earlier version, the plugin is currently NOT RUNNING.' ), WEBYX_FG_WP_MIN_VERSION );
			$html_message = sprintf( '<div class="error">%s</div>', wpautop( $message ) );
			echo wp_kses_post( $html_message );
		}
		add_action( 'admin_notices', 'webyx_fg_fail_wp_version' );
	} else {
    if ( ! class_exists( 'Webyx_FG' ) ) {
      class Webyx_FG {
        private static $instance;
        protected $templates;
        public function __construct () {
          $this->templates = array( 
            'templates/page-webyx.php' => 'webyx'
          );
          if ( function_exists( 'register_block_type' ) ) {
            add_action( 
              'init', 
              array( 
                $this, 
                'webyx_fg_register_block' 
              ) 
            );
            add_action( 
              'init', 
              array( 
                $this, 
                'webyx_fg_register_block_assets'
              ) 
            );
            add_action( 
              'init', 
              array( 
                $this, 
                'webyx_fg_register_menus' 
              ) 
            );
            add_filter( 
              'show_admin_bar', 
              array( 
                $this, 
                'webyx_fg_remove_top_admin_bar_in_preview_page' 
              ) 
            );
            self::webyx_fg_init_page_template();
            self::webyx_fg_handle_review();
          }
        }
        public static function webyx_fg_get_instance () {
          if ( null == self::$instance ) {
            self::$instance = new self();
          }
          return self::$instance;
        }
        public function webyx_fg_register_block_assets () {
          $asset_file = include( plugin_dir_path( __FILE__ ) . 'build/index.asset.php');
          wp_register_script(
            'webyx-fg-editor',
            plugins_url( 
              'build/index.js',
              __FILE__ 
            ),
            $asset_file[ 'dependencies' ],
            $asset_file[ 'version' ]
          );
          wp_register_style(
            'webyx-fg-editor',
            plugins_url( 
              'build/index.css', 
              __FILE__ 
            ),
            $asset_file[ 'version' ]
          );
        }
        public function webyx_fg_register_block () {
          register_block_type( 
            'webyx-fg/webyx-wrapper', 
            array(
              'api_version'   => 2,
              'editor_script' => 'webyx-fg-editor',
              'editor_style'  => 'webyx-fg-editor',
            ) 
          );
          register_block_type( 
            'webyx-fg/webyx-section', 
            array(
              'api_version'   => 2,
              'editor_script' => 'webyx-fg-editor',
              'editor_style'  => 'webyx-fg-editor'
            ) 
          );
          register_block_type( 
            'webyx-fg/webyx-slide', 
              array(
              'api_version'   => 2,
              'editor_script' => 'webyx-fg-editor',
              'editor_style'  => 'webyx-fg-editor'
            ) 
          );
        }
        public function webyx_fg_remove_top_admin_bar_in_preview_page () {
          return false;
        }
        public function webyx_fg_enqueue_assets_core () {
          wp_enqueue_style( 
            'webyx-core', 
            plugins_url( 
              WEBYX_FG_ASSET_MIN ? '/assets/css/webyx.min.css' : '/assets/css/webyx.css',
              __FILE__ 
            ),
            false
          );
          wp_enqueue_script( 
            'webyx-core',
            plugins_url( 
              WEBYX_FG_ASSET_MIN ? '/assets/js/webyx.min.js' : '/assets/js/webyx.js', 
              __FILE__ 
            ),
            array(),
            filemtime( 
              plugin_dir_path( __FILE__ ) . ( WEBYX_FG_ASSET_MIN ? '/assets/js/webyx.min.js' : '/assets/js/webyx.js') 
            ),
            true
          );
        }
        public function webyx_fg_init_page_template () {
          add_filter(
            'theme_page_templates', 
            array( 
              $this, 
              'webyx_fg_add_new_template' 
            )
          );
          add_filter(
            'wp_insert_post_data', 
            array( 
              $this, 
              'webyx_fg_register_project_templates' 
            ) 
          );
          add_filter(
            'template_include', 
            array( 
              $this, 
              'webyx_fg_view_project_template'
            ), 
            12
          );
        }
        public function webyx_fg_handle_review () {
          add_action( 
            'admin_init',
            array(
              $this,
              'webyx_fg_check_installation_time' 
            ) 
          );
          add_action( 
            'admin_init',
            array(
              $this, 
              'webyx_fg_spare_me'
            ), 5 
          );
          add_action( 
            'admin_enqueue_scripts',
            array(
              $this,
              'webyx_fg_admin_css' 
            )
          );
          register_activation_hook( 
            __FILE__, 
            array(
              $this,
              'webyx_fg_activation_time'
            ) 
          );
        }
        public function webyx_fg_add_new_template ( $posts_templates ) {
          $posts_templates = array_merge( $posts_templates, $this->templates );
          return $posts_templates;
        }
        public function webyx_fg_register_project_templates ( $atts ) {
          $cache_key = 'page_templates-' . md5( get_theme_root() . '/' . get_stylesheet() );
          $templates = wp_get_theme()->get_page_templates();
          if ( empty( $templates ) ) {
            $templates = array();
          } 
          wp_cache_delete( $cache_key , 'themes');
          $templates = array_merge( $templates, $this->templates );
          wp_cache_add( $cache_key, $templates, 'themes', 1800 );
          return $atts;
        }
        public function webyx_fg_view_project_template ( $template ) {
          global $post;
          $webyx_theme         = true;
          $template_webyx_page = WEBYX_FG_PATH . 'templates\page-webyx.php';
          if ( ! $post ) {
            if ( $webyx_theme ) {
              return $template_webyx_page;
            }
            self::webyx_fg_enqueue_assets_core();
            return $template;
          }
          $blocks = parse_blocks( $post->post_content );
          if ( count( $blocks ) && 'webyx-fg/webyx-wrapper' === $blocks[ 0 ][ 'blockName' ] ) {
            $template_custom_redirect = isset( $blocks[ 0 ][ 'attrs' ][ 'ctt' ]   ) ? $blocks[ 0 ][ 'attrs' ][ 'ctt' ]   : false;
            $template_custom_fn       = isset( $blocks[ 0 ][ 'attrs' ][ 'cttfn' ] ) ? $blocks[ 0 ][ 'attrs' ][ 'cttfn' ] : '';
            if ( $template_custom_redirect && $template_custom_fn ) {
              $file = get_stylesheet_directory() . '/' . $template_custom_fn;
              if ( file_exists( $file ) ) {
                self::webyx_fg_enqueue_assets_core();
                return $file;
              }
            }
          }
          $_wp_page_template = get_post_meta( $post->ID, '_wp_page_template', true );
          if ( $_wp_page_template ) {
            $file = WEBYX_FG_PATH . $_wp_page_template;
            if ( file_exists( $file ) ) {
              self::webyx_fg_enqueue_assets_core();
              return $file;
            } 
          }
          return $template;
        }
        public function webyx_fg_register_menus () {
          register_nav_menus(
            array(
              'webyx-menu' => __( 'Webyx Menu' )
            )
          );
        }
        public function webyx_fg_activation_time () {
          $webyx_fg_activation_time = strtotime( 'now' );
          add_option( 'webyx_fg_activation_time', $webyx_fg_activation_time );
          return $webyx_fg_activation_time;
        }
        public function webyx_fg_check_installation_time () {   
          $webyx_fg_activation_time       = get_option( 'webyx_fg_activation_time', $this->webyx_fg_activation_time() );
          $webyx_fg_spare_me              = get_option( 'webyx_fg_spare_me' );
          $webyx_fg_review_threshold_date = strtotime( WEBYX_FG_REVIEW_THRESHOLD_DATE );
          if ( '1' !== $webyx_fg_spare_me && ( $webyx_fg_review_threshold_date >= $webyx_fg_activation_time ) ) {
            add_action( 
              'admin_notices',
              array(
                $this,
                'webyx_fg_display_admin_notice' 
              ) 
            );
          }
        }
        public function webyx_fg_display_admin_notice () {
          global $pagenow;
          if ( 'index.php' === $pagenow ){
            $dont_disturb = esc_url( get_admin_url() . '?spare_me=1' );
            $plugin_info  = get_plugin_data( __FILE__ , true, true );       
            $reviewurl    = esc_url( 'https://wordpress.org/support/plugin/'. sanitize_title( $plugin_info[ 'Name' ] ) . '/reviews/' );
            printf(
              __( '<div class="webyx-fg-review webyx-fg-wrp">
                    <p>You have been using <b>%s</b> for a while. We hope you liked it! Please give us a quick rating, it works as a boost for us to keep working on the plugin!</p>
                    <div class="webyx-fg-review-btn">
                      <a href="%s" class="button button-primary webyx-fg-rate-now" target="_blank">Rate Now!</a>
                      <a href="%s" class="webyx-fg-review-done"> Already Done!</a>
                    </div>
                  </div>', 
              $plugin_info[ 'TextDomain' ] ), 
              $plugin_info[ 'Name' ], 
              $reviewurl, 
              $dont_disturb 
            );
          }
        }
        public function webyx_fg_spare_me () {    
          if ( isset( $_GET[ 'spare_me' ] ) && ! empty( $_GET[ 'spare_me' ] ) ) {
            $spare_me = $_GET[ 'spare_me' ];
            if ( '1' === $spare_me ) {
              add_option( 'webyx_fg_spare_me' , '1', TRUE );
            }
          }
        }
        public function webyx_fg_admin_css () {
          global $pagenow;
          if( 'index.php' === $pagenow ) {
            wp_enqueue_style( 
              'webyx-fg-admin', 
              plugins_url( 
                'assets/css/webyx-fg-admin.css', 
                __FILE__ 
              ) 
            );
          }
        }
      }
      Webyx_FG::webyx_fg_get_instance();
    }
  }